# This file is automatically generated. Please do not modify.

from . import AsciiArt

aosc_os = AsciiArt(match=r'''"AOSC OS"*''', color='4 0 1 3', ascii=r'''
${c2}                  __
               ${c2}gpBBBBBBBBBP
           ${c2}_gBBBBBBBBBRP
         ${c2}4BBBBBBBBRP  ${c4},_____
              ${c2}`"" ${c4}_g@@@@@@@@@@@@@%g>
              ${c4}__@@@@@@@@@@@@@@@@P"  ${c1}___
           ${c4}_g@@@@@@@@@@@@@@@N"` ${c1}_gN@@@@@N^
       ${c4}_w@@@@@@@@@@@@@@@@P" ${c1}_g@@@@@@@P"
    ${c4}_g@@@@@@@@@@@@@@@N"`  ${c1}VMNN@NNNM^`
  ${c4}^MMM@@@@@@@@@@@MP" ${c3},ggppww__
          ${c4}`""""" ${c3}_wNNNNNNNNNNNNNNNNNNN
              ${c3}_gBNNNNNNNNNNNNNNNNNP"
          ${c3}_wNNNNNNNNNNNNNNNNNNMP`
       ${c3}_gBNNNNNNNNNNNNNNNNNP"
   ${c3}_wNNNNNNNNNNNNNNNNNNNM^
   ${c3}""Y^^MNNNNNNNNNNNNP`
           ${c3}`"""""""
''')
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

sharklinux = AsciiArt(match=r'''"SharkLinux"*''', color='4 7', ascii=r"""
${c1}                              `:shd/
                          `:yNMMMMs
                       `-smMMMMMMN.
                     .+dNMMMMMMMMs
                   .smNNMMMMMMMMm`
                 .sNNNNNNNMMMMMM/
               `omNNNNNNNMMMMMMm
              /dNNNNNNNNMMMMMMM+
            .yNNNNNNNNNMMMMMMMN`
           +mNNNNNNNNNMMMMMMMMh
         .hNNNNNNNNNNMMMMMMMMMs
        +mMNNNNNNNNMMMMMMMMMMMs
      .hNMMNNNNMMMMMMMMMMMMMMMd
    .oNNNNNNNNNNMMMMMMMMMMMMMMMo
 `:+syyssoo++++ooooossssssssssso:
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

antergos = AsciiArt(match=r'''"Antergos"*''', color='4 6', ascii=r"""
${c2}              `.-/::/-``
            .-/osssssssso/.
           :osyysssssssyyys+-
        `.+yyyysssssssssyyyyy+.
       `/syyyyyssssssssssyyyyys-`
      `/yhyyyyysss${c1}++${c2}ssosyyyyhhy/`
     .ohhhyyyys${c1}o++/+o${c2}so${c1}+${c2}syy${c1}+${c2}shhhho.
    .shhhhys${c1}oo++//+${c2}sss${c1}+++${c2}yyy${c1}+s${c2}hhhhs.
   -yhhhhs${c1}+++++++o${c2}ssso${c1}+++${c2}yyy${c1}s+o${c2}hhddy:
  -yddhhy${c1}o+++++o${c2}syyss${c1}++++${c2}yyy${c1}yooy${c2}hdddy-
 .yddddhs${c1}o++o${c2}syyyyys${c1}+++++${c2}yyhh${c1}sos${c2}hddddy`
`odddddhyosyhyyyyyy${c1}++++++${c2}yhhhyosddddddo
.dmdddddhhhhhhhyyyo${c1}+++++${c2}shhhhhohddddmmh.
ddmmdddddhhhhhhhso${c1}++++++${c2}yhhhhhhdddddmmdy
dmmmdddddddhhhyso${c1}++++++${c2}shhhhhddddddmmmmh
-dmmmdddddddhhys${c1}o++++o${c2}shhhhdddddddmmmmd-
.smmmmddddddddhhhhhhhhhdddddddddmmmms.
   `+ydmmmdddddddddddddddddddmmmmdy/.
      `.:+ooyyddddddddddddyyso+:.`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

funtoo = AsciiArt(match=r'''"Funtoo"*''', color='5 7', ascii=r"""
${c1}   .dKXXd                         .
  :XXl;:.                      .OXo
.'OXO''  .''''''''''''''''''''':XNd..'oco.lco,
xXXXXXX, cXXXNNNXXXXNNXXXXXXXXNNNNKOOK; d0O .k
  kXX  xXo  KNNN0  KNN.       'xXNo   :c; 'cc.
  kXX  xNo  KNNN0  KNN. :xxxx. 'NNo
  kXX  xNo  loooc  KNN. oNNNN. 'NNo
  kXX  xN0:.       KNN' oNNNX' ,XNk
  kXX  xNNXNNNNNNNNXNNNNNNNNXNNOxXNX0Xl
  ...  ......................... .;cc;.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

cutefishos = AsciiArt(match=r'''"CutefishOS"*''', color='6 7 4', ascii=r"""
${c1}                     ___ww___
_              _wwMMM@M^^^^MMMMww_
M0w_       _wMMM~~             ~~MMm_
  ~MMy _ww0M~                      ~MMy
    ~MMMM~                      o    "MM
${c3}  jw0M~~MMMw_                      _wMM'
wMM~      ~~MMmw__             __w0M~
~             ~~MM0MmwwwwwwwwwMMM~
                    ~~~~^^~~~
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

linux_lite = AsciiArt(match=r'''"Linux Lite"* | "Linux_Lite"*''', color='3 7', ascii=r"""
${c1}          ,xXc
      .l0MMMMMO
   .kNMMMMMWMMMN,
   KMMMMMMKMMMMMMo
  'MMMMMMNKMMMMMM:
  kMMMMMMOMMMMMMO
 .MMMMMMX0MMMMMW.
 oMMMMMMxWMMMMM:
 WMMMMMNkMMMMMO
:MMMMMMOXMMMMW
.0MMMMMxMMMMM;
:;cKMMWxMMMMO
'MMWMMXOMMMMl
 kMMMMKOMMMMMX:
 .WMMMMKOWMMM0c
  lMMMMMWO0MNd:'
   oollXMKXoxl;.
     ':. .: .'
              ..
                .
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

arch = AsciiArt(match=r'''"Arch"*''', color='6 6 7 1', ascii=r"""
${c1}                   -`
                  .o+`
                 `ooo/
                `+oooo:
               `+oooooo:
               -+oooooo+:
             `/:-:++oooo+:
            `/++++/+++++++:
           `/++++++++++++++:
          `/+++o${c2}oooooooo${c1}oooo/`
${c2}         ${c1}./${c2}ooosssso++osssssso${c1}+`
${c2}        .oossssso-````/ossssss+`
       -osssssso.      :ssssssso.
      :osssssss/        osssso+++.
     /ossssssss/        +ssssooo/-
   `/ossssso+/:-        -:/+osssso+-
  `+sso+:-`                 `.-/+oso:
 `++:.                           `-/+/
 .`                                 `/
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

gentoo_small = AsciiArt(match=r'''"gentoo_small"''', color='5 7', ascii=r"""
${c1} _-----_
(       \
\    0   \
${c2} \        )
 /      _/
(     _-
\____-
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

postmarketos_small = AsciiArt(match=r'''"postmarketos_small"''', color='2 7', ascii=r"""
${c1}        /\
       /  \
      /    \
      \__   \
    /\__ \  _\
   /   /  \/ __
  /   / ____/  \
 /    \ \       \
/_____/ /________\
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

ubuntu_cinnamon = AsciiArt(match=r'''"Ubuntu Cinnamon"* | "Ubuntu-Cinnamon"*''', color='1 7', ascii=r"""
${c1}            .-/+oooooooo+/-.
        `:+oooooooooooooooooo+:`
      -+oooooooooooooooooooooooo+-
    .ooooooooooooooooooo${c2}:ohNd${c1}oooooo.
   /oooooooooooo${c2}:/+oo++:/ohNd${c1}ooooooo/
  +oooooooooo${c2}:osNdhyyhdNNh+:+${c1}oooooooo+
 /ooooooooo${c2}/dN/${c1}ooooooooo${c2}/sNNo${c1}ooooooooo/
.ooooooooo${c2}oMd:${c1}oooooooooooo${c2}:yMy${c1}ooooooooo.
+ooooo${c2}:+o/Md${c1}oooooo${c2}:sm/${c1}oo/ooo${c2}yMo${c1}oooooooo+
ooo${c2}:sdMdosMo${c1}ooooo${c2}oNMd${c1}//${c2}dMd+${c1}o${c2}:so${c1}ooooooooo
oooo${c2}+ymdosMo${c1}ooo${c2}+mMm${c1}+/${c2}hMMMMMh+hs${c1}ooooooooo
+oooooo${c2}:${c1}:${c2}/Nm:${c1}/${c2}hMNo${c1}:y${c2}MMMMMMMMMM+${c1}oooooooo+
.ooooooooo${c2}/NNMNy${c1}:o${c2}NMMMMMMMMMMo${c1}ooooooooo.
/oooooooooo${c2}:yh:${c1}+m${c2}MMMMMMMMMMd/${c1}ooooooooo/
  +oooooooooo${c2}+${c1}/h${c2}mMMMMMMNds//o${c1}oooooooo+
   /oooooooooooo${c2}+:////:o/ymMd${c1}ooooooo/
    .oooooooooooooooooooo${c2}/sdh${c1}oooooo.
      -+oooooooooooooooooooooooo+-
        `:+oooooooooooooooooo+:`
            .-/+oooooooo+/-.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

source_mage = AsciiArt(match=r'''"Source Mage"* | "Source_Mage"*''', color='4 7 1', ascii=r"""
${c2}       :ymNMNho.
.+sdmNMMMMMMMMMMy`
.-::/yMMMMMMMMMMMm-
      sMMMMMMMMMMMm/
     /NMMMMMMMMMMMMMm:
    .MMMMMMMMMMMMMMMMM:
    `MMMMMMMMMMMMMMMMMN.
     NMMMMMMMMMMMMMMMMMd
     mMMMMMMMMMMMMMMMMMMo
     hhMMMMMMMMMMMMMMMMMM.
     .`/MMMMMMMMMMMMMMMMMs
        :mMMMMMMMMMMMMMMMN`
         `sMMMMMMMMMMMMMMM+
           /NMMMMMMMMMMMMMN`
             oMMMMMMMMMMMMM+
          ./sd.-hMMMMMMMMmmN`
      ./+oyyyh- `MMMMMMMMMmNh
                 sMMMMMMMMMmmo
                 `NMMMMMMMMMd:
                  -dMMMMMMMMMo
                    -shmNMMms.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

rosa = AsciiArt(match=r'''"Rosa"*''', color='4 7 1', ascii=r"""
${c1}           ROSAROSAROSAROSAR
        ROSA               AROS
      ROS   SAROSAROSAROSAR   AROS
    RO   ROSAROSAROSAROSAROSAR   RO
  ARO  AROSAROSAROSARO      AROS  ROS
 ARO  ROSAROS         OSAR   ROSA  ROS
 RO  AROSA   ROSAROSAROSA    ROSAR  RO
RO  ROSAR  ROSAROSAROSAR  R  ROSARO  RO
RO  ROSA  AROSAROSAROSA  AR  ROSARO  AR
RO AROS  ROSAROSAROSA   ROS  AROSARO AR
RO AROS  ROSAROSARO   ROSARO  ROSARO AR
RO  ROS  AROSAROS   ROSAROSA AROSAR  AR
RO  ROSA  ROS     ROSAROSAR  ROSARO  RO
 RO  ROS     AROSAROSAROSA  ROSARO  AR
 ARO  ROSA   ROSAROSAROS   AROSAR  ARO
  ARO  OROSA      R      ROSAROS  ROS
    RO   AROSAROS   AROSAROSAR   RO
     AROS   AROSAROSAROSARO   AROS
        ROSA               SARO
           ROSAROSAROSAROSAR
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

kibojoe = AsciiArt(match=r'''"Kibojoe"*''', color='2 7 4', ascii=r"""
            ${c3}           ./+oooooo+/.
           -/+ooooo+/:.`
          ${c1}`${c3}yyyo${c2}+++/++${c3}osss${c1}.
         ${c1}+NMN${c3}yssssssssssss${c1}.
       ${c1}.dMMMMN${c3}sssssssssssy${c1}Ns`
      +MMMMMMMm${c3}sssssssssssh${c1}MNo`
    `hMMMMMNNNMd${c3}sssssssssssd${c1}MMN/
   .${c3}syyyssssssy${c1}NNmmmmd${c3}sssss${c1}hMMMMd:
  -NMmh${c3}yssssssssyhhhhyssyh${c1}mMMMMMMMy`
 -NMMMMMNN${c3}mdhyyyyyyyhdm${c1}NMMMMMMMMMMMN+
`NMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMd.
ods+/:-----://+oyydmNMMMMMMMMMMMMMMMMMN-
`                     .-:+osyhhdmmNNNmdo
""")
    


import json
from collections import Counter
from pathlib import Path

from openai import OpenAI

client = OpenAI()

if __name__ == '__main__':
    # Read reddit data
    # data = json.loads(Path('reddit.json').read_text('utf-8'))
    data = json.loads(Path('reddit_opinions.json').read_text('utf-8'))

    # Testing: Print all comments
    for cmt in data:
        print()
        print(f"{cmt['author']}")
        print(f"- {cmt['content']}")

    # Loop through each comment, ask GPT-4o to generate a verdict on
    # whether this comment support or oppose adding the flag
    opinions = []
    for cmt in data:
        if 'opinion' in cmt:
            opinions.append(cmt)
            continue

        out = client.chat.completions.create(
            model="gpt-4o",
            messages=[
                {"role": "system", "content": "You are a data analyst asked to read reddit comments on a thread collecting "
                                              "opinions on adding the Hypersexual flag into a LGBT+ system information tool."},
                # One-shot learning example
                {"role": "user", "content": "Does the following comment support or oppose adding the flag? Please answer 'support' or 'oppose' or 'neutral'.\n\n"
                                            "Author: azaneko • 1d ago\nComment: I'd like a flag"},
                {"role": "system", "content": "Support"},
                # Asking the actual data
                {"role": "user", "content": "Does the following comment support or oppose adding the flag? Please answer 'support' or 'oppose' or 'neutral'.\n\n"
                                            f"Author: {cmt['author']}\nComment: {cmt['content']}"},
            ],
        )

        # Print the result
        res = out.choices[0].message.content.lower().strip()
        print("\n")
        print("Author:", cmt['author'])
        print("Comment:", cmt['content'])
        print("Opinion:", res)
        opinions.append({**cmt, 'opinion': res})
        Path('reddit_opinions.json').write_text(json.dumps(opinions, indent=2))

    # Count opinions and upvotes
    counter = Counter()
    for cmt in opinions:
        counter[cmt['opinion']] += cmt.get('upvotes') or 0

    print("\n")
    print("Opinions:")
    for k, v in counter.items():
        print(f"{k}: {v}")



import math
from time import sleep

from hyfetch import presets
from hyfetch.color_util import RGB, color, printc
from hyfetch.constants import IS_WINDOWS
from hyfetch.neofetch_util import term_size
from hyfetch.presets import PRESETS


def key_pressed():
    if IS_WINDOWS:
        import msvcrt
        return msvcrt.kbhit()  # Non-blocking check for key press
    else:
        import select
        import sys
        return select.select([sys.stdin], [], [], 0) == ([sys.stdin], [], [])


def start_animation():
    text = r"""
.======================================================.
| .  .              .__       .     .  .       , .   | |
| |__| _.._ ._   .  [__)._.* _| _   |\/| _ ._ -+-|_  | |
| |  |(_][_)[_)\_|  |   [  |(_](/,  |  |(_)[ ) | [ ) * |
|        |  |  ._|                                     |
'======================================================'""".strip("\n")
    text_lines = text.split("\n")
    text_height = len(text_lines)
    text_width = len(text_lines[0])

    notice = "Press enter to continue"

    speed = 2
    frame_delay = 1 / 25

    colors: list[RGB] = []
    frame = 0

    w, h = term_size()
    blocks = 9
    block_width = w // blocks

    text_start_y = h // 2 - text_height // 2
    text_end_y = text_start_y + text_height
    text_start_x = w // 2 - text_width // 2
    text_end_x = text_start_x + text_width

    notice_start_x = w - len(notice) - 1
    notice_end_x = w - 1
    notice_y = h - 1

    # Add everything in PRESETS to colors
    colors = [c for preset in PRESETS.values() for c in preset.colors]

    black = RGB(0, 0, 0)
    fg = RGB.from_hex("#FFE09B")

    def draw_frame():
        buf = ""

        # Loop over the height
        for y in range(h):
            # Print the starting color
            buf += colors[((frame + y) // block_width) % len(colors)].to_ansi_rgb(foreground=False)
            buf += fg.to_ansi_rgb(foreground=True)

            # Loop over the width
            x = 0
            while x < w:
                idx = frame + x + y + int(math.sin(y + 0.5 * frame) * 2)
                y_text = text_start_y <= y < text_end_y

                border = 1 + int(not (y == text_start_y or y == text_end_y - 1))

                # If it's a switching point
                if idx % block_width == 0 or x == text_start_x - border or x == text_end_x + border \
                        or x == notice_start_x - 1 or x == notice_end_x + 1:
                    # Print the color at the current frame
                    c = colors[(idx // block_width) % len(colors)]
                    if (y_text and text_start_x - border <= x < text_end_x + border) \
                            or (y == notice_y and notice_start_x - 1 <= x < notice_end_x + 1):
                        # buf += c.set_light(0.3).to_ansi_rgb(foreground=False)
                        buf += c.overlay(black, 0.5).to_ansi_rgb(foreground=False)
                    else:
                        buf += c.to_ansi_rgb(foreground=False)

                # If text should be printed, print text
                if y_text and text_start_x <= x < text_end_x:
                    # Add white background
                    buf += text_lines[y - text_start_y][x - text_start_x]
                elif y == notice_y and notice_start_x <= x < notice_end_x:
                    buf += notice[x - notice_start_x]
                else:
                    buf += ' '

                x += 1

            # New line if it isn't the last line
            if y != h - 1:
                buf += color('&r\n')

        print(buf, end='', flush=True)

    try:
        while 1:
            # Move cursor to the top left corner
            print("\033[H", end="")
            draw_frame()
            frame += speed
            sleep(frame_delay)

            if key_pressed():
                break
    except KeyboardInterrupt:
        pass

    # Clear the screen
    printc("&r")
    print("\033[2J\033[H", end="", flush=True)


if __name__ == '__main__':
    start_animation()





# This file is automatically generated. Please do not modify.

from . import AsciiArt

garuda_small = AsciiArt(match=r'''"garuda_small"''', color='7 7 3 7 2 4', ascii=r"""
${c3}     .----.
   .'   ${c6},${c3}  '.
${c4} .'    ${c6}'${c3}-----|
'${c5}.   -----,
  '.____.'
""")
    


import re, json

distro_color = {}


def color(colornum):  # see neofetch color()
    reset = "\e[0m"
    ascii_bold = "\e[1m"
    if colornum == "fg" or colornum == "7":
        return f"\e[37m{reset}"
    if colornum == "#":
        pass  # TODO
    if int(colornum) >= 0 and int(colornum) < 7:
        return f"{reset}\e[3{colornum}m"
    return f"\e38;5;{colornum}m"


with open("neofetch") as f:
    s = f.read()
l = iter(s.split("\n"))
for i in l:
    p = re.search(r'"\D+"\*\)', i)
    if p is None:
        continue
    distros = re.sub(r"\"|\)|\*", "", i.strip(" ")).split("|")
    c = next(l).strip(" ")
    if "set_colors" not in c:
        continue
    colors = c.split(" ")[1:]
    for dist in distros:
        distro_color[dist.strip(" ").rstrip(" ")] = colors
with open("distcolor.json", "w") as f:
    json.dump(distro_color, f)



# This file is automatically generated. Please do not modify.

from . import AsciiArt

raspbian_small = AsciiArt(match=r'''"Raspbian_small"*''', color='2 1', ascii=r"""
${c1}   ..    ,.
  :oo: .:oo:
  'o\o o/o:
${c2} :: . :: . ::
:: :::  ::: ::
:'  '',.''  ':
 ::: :::: :::
 ':,  ''  ,:'
   ' ~::~ '
""")
    


import argparse
import hashlib
import io
from base64 import urlsafe_b64encode
from pathlib import Path
from typing import BinaryIO, Generator, Tuple, Any

"""
The read_chunks, hash_file, and rehash functions below comes from pip._internal
They are copied to ensure compatibility with future python versions.
https://github.com/pypa/pip/blob/612515d2e0a6ff8676c139c096a45bc28b3456f4/src/pip/_internal/operations/install/wheel.py#L80
"""


def read_chunks(file: BinaryIO, size: int = io.DEFAULT_BUFFER_SIZE) -> Generator[bytes, None, None]:
    """Yield pieces of data from a file-like object until EOF."""
    while True:
        chunk = file.read(size)
        if not chunk:
            break
        yield chunk


def hash_file(path: Path, blocksize: int = 1 << 20) -> Tuple[Any, int]:
    """Return (hash, length) for path using hashlib.sha256()"""

    h = hashlib.sha256()
    length = 0
    with open(path, "rb") as f:
        for block in read_chunks(f, size=blocksize):
            length += len(block)
            h.update(block)
    return h, length


def rehash(path: Path, blocksize: int = 1 << 20) -> Tuple[str, str]:
    """Return (encoded_digest, length) for path using hashlib.sha256()"""
    h, length = hash_file(path, blocksize)
    digest = "sha256=" + urlsafe_b64encode(h.digest()).decode("latin1").rstrip("=")
    return digest, str(length)


if __name__ == '__main__':
    agupa = argparse.ArgumentParser()
    agupa.add_argument("base_path", help="The path of the wheel")
    args = agupa.parse_args()

    base_path = Path(args.base_path)

    # Find the name of the dist-info path
    dist_info = next(base_path.rglob("*.dist-info"))

    # Delete dist_info / record
    record = dist_info / "RECORD"
    order = record.read_text().splitlines()
    record.unlink()

    # Rehash each file in the wheel
    processed = set()
    new_record = []
    for file in order:
        file = base_path / file.split(',')[0]
        if file.exists():
            digest, length = rehash(file)
            new_record.append(f"{str(file.relative_to(base_path)).replace("\\", "/")},{digest},{length}")
            processed.add(file)

    for file in base_path.rglob('*'):
        if file.is_file() and file not in processed:
            digest, length = rehash(file)
            new_record.append(f"{str(file.relative_to(base_path)).replace("\\", "/")},{digest},{length}")

    new_record.append(f"{str(dist_info.relative_to(base_path)).replace("\\", "/")}/RECORD,,")

    # Write the new record
    record.write_text('\n'.join(new_record))
    print("Rehashed successfully")




#!/usr/bin/env python3
import argparse
import json
import os
import re
import shlex
import stat
import subprocess
from pathlib import Path

from packaging import version as pv

from tools.list_distros import generate_help, export_distros
from tools.reformat_readme import reformat_readme

NEOFETCH_NEW_VERSION = ""


def pre_check():
    """
    Check source code status before releasing.
    """
    assert os.path.isfile('./neofetch'), './neofetch doesn\'t exist, you are running this script in the wrong directory'
    assert os.stat('./neofetch').st_mode & stat.S_IEXEC, 'neofetch is not executable'
    assert os.path.islink('./hyfetch/scripts/neowofetch'), 'neowofetch is not a symbolic link'
    # subprocess.check_call(shlex.split('git diff-index --quiet HEAD --'))  # 'Please commit all changes before release'

    print('Running shellcheck... (This may take a while)')
    subprocess.check_call(shlex.split('shellcheck neofetch'))


def edit_versions(version: str):
    """
    Edit version numbers in hyfetch/constants.py, package.json, and README.md

    Also edits version number of neofetch, but the neofetch version number is separate.

    :param version: Version to release
    """
    # 1. package.json
    print('Editing package.json...')
    path = Path('package.json')
    content = json.loads(path.read_text())
    cur = pv.parse(content['version'])
    assert cur < pv.parse(version), 'Version did not increase'
    content['version'] = version
    path.write_text(json.dumps(content, ensure_ascii=False, indent=2))

    # 2. hyfetch/constants.py
    print('Editing hyfetch/__version__.py...')
    path = Path('hyfetch/__version__.py')
    content = [f"VERSION = '{version}'" if l.startswith('VERSION = ') else l for l in path.read_text().split('\n')]
    path.write_text('\n'.join(content))
    
    # 3. Cargo.toml
    print('Editing Cargo.toml...')
    path = Path('Cargo.toml')
    content = path.read_text()
    content = re.sub(r'(?<=^version = ")[^"]+(?="$)', version, content, flags=re.MULTILINE)
    path.write_text(content)

    # 4. README.md
    print('Editing README.md...')
    path = Path('README.md')
    content = path.read_text()
    changelog_token = '<!-- CHANGELOG STARTS HERE --->'
    changelog_i = content.index(changelog_token) + len(changelog_token)
    content = content[:changelog_i] + f'\n\n### {version}' + content[changelog_i:]
    path.write_text(content)

    # 5. neofetch script
    print('Editing neofetch...')
    path = Path('neofetch')
    lines = path.read_text().replace("\t", "        ").split('\n')
    version_i = next(i for i, l in enumerate(lines) if l.startswith('version='))
    nf = pv.parse(lines[version_i].replace('version=', ''))
    new = pv.parse(version)
    nf = f'{nf.major + new.major - cur.major}.{nf.minor + new.minor - cur.minor}.{nf.micro + new.micro - cur.micro}'
    lines[version_i] = f"version={nf}"
    path.write_text('\n'.join(lines))

    global NEOFETCH_NEW_VERSION
    NEOFETCH_NEW_VERSION = nf


def finalize_neofetch():
    """
    Finalize current version
    """
    # 1. Update distro list
    print('Updating distro list in neofetch...')
    path = Path('neofetch')
    content = path.read_text()
    content = re.compile(r'(?<=# Flag:    --ascii_distro\n#\n).*?(?=ascii_distro=)', re.DOTALL)\
        .sub(generate_help(100, '# ') + '\n', content)
    content = re.compile(r"""(?<=Which Distro's ascii art to print\n\n).*?{distro}_small to use them\.""", re.DOTALL)\
        .sub(generate_help(100, ' ' * 32), content)
    path.write_text(content)

    # 2. Regenerate man page
    print('Regenerating neofetch man page...')
    Path('docs/neofetch.1').write_text(subprocess.check_output(['help2man', './neofetch']).decode())
    Path('docs/hyfetch.1').write_text(subprocess.check_output(['help2man', 'cargo run --']).decode())

    # 3. Reformat readme links
    print('Reformatting readme links...')
    reformat_readme()


def post_check():
    """
    Check after changes are made
    """
    print('Running shellcheck... (This may take a while)')
    subprocess.check_call(shlex.split('shellcheck neofetch'))


def create_release(v: str):
    """
    Create release commit and tag
    """
    print('Committing changes...')

    # 1. Add files
    subprocess.check_call(['git', 'add', '.'])

    # 2. Commit
    subprocess.check_call(['git', 'commit', '-m', f'[U] Release {v}'])

    # 3. Create tag
    subprocess.check_call(['git', 'tag', v])
    subprocess.check_call(['git', 'tag', f'neofetch-{NEOFETCH_NEW_VERSION}'])

    i = input('Please check the commit is correct. Press y to continue or any other key to cancel.')
    if i.lower() != 'y':
        print('Aborting...')
        subprocess.check_call(['git', 'reset', '--hard', 'HEAD~1'])
        subprocess.check_call(['git', 'tag', '-d', v])
        subprocess.check_call(['git', 'tag', '-d', f'neofetch-{NEOFETCH_NEW_VERSION}'])
        exit(1)

    # 4. Push
    print('Pushing commits...')
    subprocess.check_call(['git', 'push'])
    subprocess.check_call(['git', 'push', 'origin', v, f'neofetch-{NEOFETCH_NEW_VERSION}'])


def deploy():
    """
    Deploy release to pip and npm
    """
    print('Deploying to pypi...')
    subprocess.check_call(['bash', 'tools/deploy.sh'])
    print('Done!')
    
    print('Deploying to crates.io...')
    subprocess.check_call(['bash', 'tools/deploy-crate.sh'])
    print('Done!')

    print('Deploying to npm...')
    otp = input('Please provide 2FA OTP for NPM: ')
    subprocess.check_call(['npm', 'publish', '--otp', otp])
    print('Done!')


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='HyFetch Release Utility')
    parser.add_argument('version', help='Version to release')

    args = parser.parse_args()

    pre_check()
    export_distros()
    edit_versions(args.version)
    finalize_neofetch()
    post_check()
    create_release(args.version)
    deploy()




# This file is automatically generated. Please do not modify.

from . import AsciiArt

mx_small = AsciiArt(match=r'''"mx_small"*''', color='4 6 7', ascii=r"""
${c3}    \\  /
     \\/
      \\
   /\/ \\
  /  \  /\
 /    \/  \
/__________\
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

gnewsense = AsciiArt(match=r'''"gNewSense"*''', color='4 5 7 6', ascii=r"""
${c1}                     ..,,,,..
               .oocchhhhhhhhhhccoo.
        .ochhlllllllc hhhhhh ollllllhhco.
    ochlllllllllll hhhllllllhhh lllllllllllhco
 .cllllllllllllll hlllllo  +hllh llllllllllllllc.
ollllllllllhco''  hlllllo  +hllh  ``ochllllllllllo
hllllllllc'       hllllllllllllh       `cllllllllh
ollllllh          +llllllllllll+          hllllllo
 `cllllh.           ohllllllho           .hllllc'
    ochllc.            ++++            .cllhco
       `+occooo+.                .+ooocco+'
              `+oo++++      ++++oo+'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

blankon = AsciiArt(match=r'''"BlankOn"*''', color='1 7 3', ascii=r"""
${c2}        `./ohdNMMMMNmho+.` ${c1}       .+oo:`
${c2}      -smMMMMMMMMMMMMMMMMmy-`    ${c1}`yyyyy+
${c2}   `:dMMMMMMMMMMMMMMMMMMMMMMd/`  ${c1}`yyyyys
${c2}  .hMMMMMMMNmhso/++symNMMMMMMMh- ${c1}`yyyyys
${c2} -mMMMMMMms-`         -omMMMMMMN-${c1}.yyyyys
${c2}.mMMMMMMy.              .yMMMMMMm:${c1}yyyyys
${c2}sMMMMMMy                 `sMMMMMMh${c1}yyyyys
${c2}NMMMMMN:                  .NMMMMMN${c1}yyyyys
${c2}MMMMMMm.                   NMMMMMN${c1}yyyyys
${c2}hMMMMMM+                  /MMMMMMN${c1}yyyyys
${c2}:NMMMMMN:                :mMMMMMM+${c1}yyyyys
${c2} oMMMMMMNs-            .sNMMMMMMs.${c1}yyyyys
${c2}  +MMMMMMMNho:.`  `.:ohNMMMMMMNo ${c1}`yyyyys
${c2}   -hMMMMMMMMNNNmmNNNMMMMMMMMh-  ${c1}`yyyyys
${c2}     :yNMMMMMMMMMMMMMMMMMMNy:`   ${c1}`yyyyys
${c2}       .:sdNMMMMMMMMMMNds/.      ${c1}`yyyyyo
${c2}           `.:/++++/:.`           ${c1}:oys+.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

namib = AsciiArt(match=r'''"Namib"*''', color='1', ascii=r"""
${c1}          .:+shysyhhhhysyhs+:.
       -/yyys              syyy/-
     -shy                      yhs-
   -yhs                          shy-
  +hy                              yh+
 +ds                                sd+
/ys                  so              sy/
sh                 smMMNdyo           hs
yo               ymMMMMNNMMNho        oy
N             ydMMMNNMMMMMMMMMmy       N
N         shmMMMMNNMMMMMMMMMMMMMNy     N
yo  ooshmNMMMNNNNMMMMMMMMMMMMMMMMMms  oy
sd yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy ds
/ys                                  sy/
 +ds                                sd+
  +hy                              yh+
   -yhs                          shy-
     -shy                      yhs-
       -/yyys              syyy/-
          .:+shysyhyhhysyhs+:.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

alter = AsciiArt(match=r'''"Alter"*''', color='6 6', ascii=r"""
${c1}                      %,
                    ^WWWw
                   'wwwwww
                  !wwwwwwww
                 #`wwwwwwwww
                @wwwwwwwwwwww
               wwwwwwwwwwwwwww
              wwwwwwwwwwwwwwwww
             wwwwwwwwwwwwwwwwwww
            wwwwwwwwwwwwwwwwwwww,
           w~1i.wwwwwwwwwwwwwwwww,
         3~:~1lli.wwwwwwwwwwwwwwww.
        :~~:~?ttttzwwwwwwwwwwwwwwww
       #<~:~~~~?llllltO-.wwwwwwwwwww
      #~:~~:~:~~?ltlltlttO-.wwwwwwwww
     @~:~~:~:~:~~(zttlltltlOda.wwwwwww
    @~:~~: ~:~~:~:(zltlltlO    a,wwwwww
   8~~:~~:~~~~:~~~~_1ltltu          ,www
  5~~:~~:~~:~~:~~:~~~_1ltq             N,,
 g~:~~:~~~:~~:~~:~:~~~~1q                N,
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

yiffos = AsciiArt(match=r'''"yiffOS"*''', color='93 92', ascii=r"""
${c1}            NK
             NxKXW
             WOlcoXW
             0olccloxNW
             XxllllllloxOKNW
             Nklllllllllllodk0XWW
            N0dllllllllllllllodxOKNW
          WKxlllllllllllllllllllooxOKN
        WKdllllllllllllllooooooooooooo
       Nxllllllllllllllloooooooooo${c2}oooo
${c1}     XXNOolllllllllllloooooooooo${c2}oooooo
${c1}   WX0xolllllllllllooooooooooo${c2}oooooooo
${c1} XWN0xolllllllllloooooooo${c2}ooooooooooooo
${c1}   Kkdolllllllooooddddd${c2}doooooooooooddo
${c1}        K00XNW${c2}      WX0xdooooooddddddd
                       WXOxdoooooodddd
                          WXOxdddddddd
                                NX0ddd
                                  WN0d
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

evolutionos = AsciiArt(match=r'''"EvolutionOS"*''', color='4 7', ascii=r"""
${c1}\e[1;32m      dddddddddddddddddddddddd
  .dddd''''''''''''''''''''''dddd.
  dd:   dddddddddddddddddddd;   dd:
  dd:   ldl:''''''''''''''''    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl: ddddddd;  ddddd;   dd:
  dd:   ldl: '''''''   '''''    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl: ddddddddddddddd;   dd:
  dddd:.'''  '''''''''''''''  dddd:
     dddddddddddddddddddddddddd;;'
      '''''''''''''''''''''''''\e[0m
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

bodhi = AsciiArt(match=r'''"Bodhi"*''', color='7 11 2', ascii=r"""
${c1}|           ${c2},,mmKKKKKKKKWm,,
 ${c1}'      ${c2},aKKP${c1}LL**********|L*${c2}TKp,
   ${c1}t  ${c2}aKP${c1}L**```          ```**L${c2}*Kp
    IX${c1}EL${c3}L,wwww,              ${c1}``*||${c2}Kp
  ,#P${c1}L|${c3}KKKpPP@IPPTKmw,          ${c1}`*||${c2}K
 ,K${c1}LL*${c3}{KKKKKKPPb$KPhpKKPKp        ${c1}`||${c2}K
 #${c1}PL  ${c3}!KKKKKKPhKPPP$KKEhKKKKp      ${c1}`||${c2}K
!H${c1}L*   ${c3}1KKKKKKKphKbPKKKKKK$KKp      ${c1}`|I${c2}W
$${c1}bL     ${c3}KKKKKKKKBQKhKbKKKKKKKK       ${c1}|I${c2}N
$${c1}bL     ${c3}!KKKKKKKKKKNKKKKKKKPP`       ${c1}|I${c2}b
TH${c1}L*     ${c3}TKKKKKK##KKKN@KKKK^         ${c1}|I${c2}M
 K@${c1}L      ${c3}*KKKKKKKKKKKEKE5          ${c1}||${c2}K
 `NL${c1}L      ${c3}`KKKKKKKKKK"```|L       ${c1}||${c2}#P
  `K@${c1}LL       ${c3}`"**"`        ${c1}'.   :||${c2}#P
    Yp${c1}LL                      ${c1}' |L${c2}$M`
     `Tp${c1}pLL,                ,|||${c2}p'L
        "Kpp${c1}LL++,.,    ,,|||$${c2}#K*   ${c1}'.
           ${c2}`"MKWpppppppp#KM"`        ${c1}`h,
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

neptune = AsciiArt(match=r'''"Neptune"*''', color='7', ascii=r"""
${c1}            ./+sydddddddys/-.
        .+ymNNdyooo/:+oooymNNmy/`
     `/hNNh/.`             `-+dNNy:`
    /mMd/.          .++.:oy/   .+mMd-
  `sMN/             oMMmdy+.     `oNNo
 `hMd.           `/ymy/.           :NMo
 oMN-          `/dMd:               /MM-
`mMy          -dMN+`                 mMs
.MMo         -NMM/                   yMs
 dMh         mMMMo:`                `NMo
 /MM/        /ymMMMm-               sMN.
  +Mm:         .hMMd`              oMN/
   +mNs.      `yNd/`             -dMm-
    .yMNs:    `/.`            `/yNNo`
      .odNNy+-`           .:ohNNd/.
         -+ymNNmdyyyyyyydmNNmy+.
             `-//sssssss//.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

septor = AsciiArt(match=r'''"Septor"*''', color='4 7 4', ascii=r"""
${c1}ssssssssssssssssssssssssssssssssssssssss
ssssssssssssssssssssssssssssssssssssssss
ssssssssssssssssssssssssssssssssssssssss
ssssssssssssssssssssssssssssssssssssssss
ssssssssss${c2};okOOOOOOOOOOOOOOko;${c1}ssssssssss
sssssssss${c2}oNWWWWWWWWWWWWWWWWWWNo${c1}sssssssss
ssssssss${c2}:WWWWWWWWWWWWWWWWWWWWWW:${c1}ssssssss
ssssssss${c2}lWWWWWk${c1}ssssssssss${c2}lddddd:${c1}ssssssss
ssssssss${c2}cWWWWWNKKKKKKKKKKKKOx:${c1}ssssssssss
${c3}yy${c1}sssssss${c2}OWWWWWWWWWWWWWWWWWWWWx${c1}sssssss${c3}yy
yyyyyyyyyy${c2}:kKNNNNNNNNNNNNWWWWWW:${c3}yyyyyyyy
yyyyyyyy${c2}sccccc;${c3}yyyyyyyyyy${c2}kWWWWW:${c3}yyyyyyyy
yyyyyyyy${c2}:WWWWWWNNNNNNNNNNWWWWWW;${c3}yyyyyyyy
yyyyyyyy${c2}.dWWWWWWWWWWWWWWWWWWWNd${c3}yyyyyyyyy
yyyyyyyyyy${c2}sdO0KKKKKKKKKKKK0Od;${c3}yyyyyyyyyy
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

obarun = AsciiArt(match=r'''"Obarun"*''', color='6 6 7 1', ascii=r"""
${c1}                    ,;::::;
                ;cooolc;,
             ,coool;
           ,loool,
          loooo;
        :ooool
       cooooc            ,:ccc;
      looooc           :oooooool
     cooooo          ;oooooooooo,
    :ooooo;         :ooooooooooo
    oooooo          oooooooooooc
   :oooooo         :ooooooooool
   loooooo         ;oooooooool
   looooooc        .coooooooc
   cooooooo:           ,;co;
   ,ooooooool;       ,:loc
    cooooooooooooloooooc
     ;ooooooooooooool;
       ;looooooolc;
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

parabola = AsciiArt(match=r'''"Parabola"*''', color='5 7', ascii=r"""
${c1}                          `.-.    `.
                   `.`  `:++.   `-+o+.
             `` `:+/. `:+/.   `-+oooo+
        ``-::-.:+/. `:+/.   `-+oooooo+
    `.-:///-  ..`   .-.   `-+oooooooo-
 `..-..`                 `+ooooooooo:
``                        :oooooooo/
                          `ooooooo:
                          `oooooo:
                          -oooo+.
                          +ooo/`
                         -ooo-
                        `+o/.
                        /+-
                       //`
                      -.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

openindiana = AsciiArt(match=r'''"OpenIndiana"*''', color='4 7 1', ascii=r"""
${c2}                         .sy/
                         .yh+

           ${c1}-+syyyo+-     ${c2} /+.
         ${c1}+ddo/---/sdh/   ${c2} ym-
       ${c1}`hm+        `sms${c2}   ym-```````.-.
       ${c1}sm+           sm/ ${c2} ym-         +s
       ${c1}hm.           /mo ${c2} ym-         /h
       ${c1}omo           ym: ${c2} ym-       `os`
        ${c1}smo`       .ym+ ${c2}  ym-     .os-
     ``  ${c1}:ymy+///oyms- ${c2}   ym-  .+s+.
   ..`     ${c1}`:+oo+/-`  ${c2}    -//oyo-
 -:`                   .:oys/.
+-               `./oyys/.
h+`      `.-:+oyyyo/-`
`/ossssysso+/-.`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

carbs = AsciiArt(match=r'''"Carbs"*''', color='4 5 4 4 4 4', ascii=r"""
${c2}             ..........
          ..,;:ccccccc:;'..
       ..,clllc:;;;;;:cllc,.
      .,cllc,...     ..';;'.
     .;lol;..           ..
    .,lol;.
    .coo:.
   .'lol,.
   .,lol,.
   .,lol,.
    'col;.
    .:ooc'.
    .'col:.
     .'cllc'..          .''.
      ..:lolc,'.......',cll,.
        ..;cllllccccclllc;'.
          ...',;;;;;;,,...
                .....
""")
    


#!/usr/bin/env python3
from pathlib import Path
from setuptools import setup, find_namespace_packages

# The directory containing this file
HERE = Path(__file__).parent

# Load version without importing it (see issue #192 if you are confused)
VERSION = [l for l in (HERE / "Cargo.toml").read_text('utf-8').splitlines() if l.startswith("version = ")]
if len(VERSION) != 1:
    raise ValueError(f"Cannot determine version from Cargo.toml: {VERSION}")
VERSION = VERSION[0].split('"')[1]

# The text of the README file
README = (HERE / "README.md").read_text('utf-8')

# This call to setup() does all the work
setup(
    name="HyFetch",
    version=VERSION,
    description="neofetch with flags <3",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/hykilpikonna/HyFetch",
    author="Azalea Gui",
    author_email="me@hydev.org",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
    ],
    packages=find_namespace_packages(exclude=("tools", "tools.*")),
    package_data={'hyfetch': ['hyfetch/*']},
    include_package_data=True,
    install_requires=[
        # Universal dependencies
        'typing_extensions; python_version < "3.8"',
        
        # Windows dependencies
        'psutil ; platform_system=="Windows"',
        'colorama>=0.4.6 ; platform_system=="Windows"',
    ],
    entry_points={
        "console_scripts": [
            "hyfetch.v1=hyfetch.__main__:run_py",
            "hyfetch.rs=hyfetch.__main__:run_rust",
            "hyfetch=hyfetch.__main__:run_rust",
        ]
    },
    scripts=['hyfetch/scripts/neowofetch']
)



# This file is automatically generated. Please do not modify.

from . import AsciiArt

openkylin = AsciiArt(match=r'''"openKylin"*''', color='2 7', ascii=r"""
${c1}
             /KKK]
            KKKKKKK`   ]KKKK\
           KKKKK/  /KKKKKKKKK\
          KKKK/ ,KKKKKKKKKKKK^
  ,]KKK  =KKK` /KKKKKKOOOOOO`
,KKKKKK  =KK  /`    [\OOOOOOO\
 \KKKKK  =K            ,OOOOOOO`
 ,KKKKK  =^              \OOOOOO
  ,KKKK   ^               OOOOOO^
   *KKK^                  =OOOOO^
    OOKK^                 OOOOOO^
    \OOOK\               /OOOOOO`
     OOOOOO]           ,OOOOOOO^
     ,OOOOOOOO\]   ,[OOOOOOOOO/
       \OOOOOOOOOOOOOOOOOOOOO`
         [OOOOOOOOOOOOOOOO/`
            ,[OOOOOOOOO]
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

ubuntu = AsciiArt(match=r'''"Ubuntu"*''', color='1', ascii=r"""
${c1}                             ....
              .',:clooo:  .:looooo:.
           .;looooooooc  .oooooooooo'
        .;looooool:,''.  :ooooooooooc
       ;looool;.         'oooooooooo,
      ;clool'             .cooooooc.  ,,
         ...                ......  .:oo,
  .;clol:,.                        .loooo'
 :ooooooooo,                        'ooool
'ooooooooooo.                        loooo.
'ooooooooool                         coooo.
 ,loooooooc.                        .loooo.
   .,;;;'.                          ;ooooc
       ...                         ,ooool.
    .cooooc.              ..',,'.  .cooo.
      ;ooooo:.           ;oooooooc.  :l.
       .coooooc,..      coooooooooo.
         .:ooooooolc:. .ooooooooooo'
           .':loooooo;  ,oooooooooc
               ..';::c'  .;loooo:'
                             .
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

blag = AsciiArt(match=r'''"BLAG"*''', color='5 7', ascii=r"""
${c1}             d
            ,MK:
            xMMMX:
           .NMMMMMX;
           lMMMMMMMM0clodkO0KXWW:
           KMMMMMMMMMMMMMMMMMMX'
      .;d0NMMMMMMMMMMMMMMMMMMK.
 .;dONMMMMMMMMMMMMMMMMMMMMMMx
'dKMMMMMMMMMMMMMMMMMMMMMMMMl
   .:xKWMMMMMMMMMMMMMMMMMMM0.
       .:xNMMMMMMMMMMMMMMMMMK.
          lMMMMMMMMMMMMMMMMMMK.
          ,MMMMMMMMWkOXWMMMMMM0
          .NMMMMMNd.     `':ldko
           OMMMK:
           oWk,
           ;:
""")
    


from __future__ import annotations

import os
import platform
from dataclasses import dataclass
from pathlib import Path

from .types import LightDark
from .__version__ import VERSION

CONFIG_PATH = Path.home() / '.config/hyfetch.json'


TEST_ASCII = r"""
### |\___/| ###
### )     ( ###
## =\     /= ##
#### )===( ####
### /     \ ###
### |     | ###
## / {txt} \ ##
## \       / ##
_/\_\_   _/_/\_
|##|  ( (  |##|
|##|   ) ) |##|
|##|  (_(  |##|""".strip('\n')

TEST_ASCII_WIDTH = max(len(line) for line in TEST_ASCII.split('\n'))
DEFAULT_DARK_L = 0.
IS_WINDOWS = platform.system() == 'Windows'

CACHE_PATH = Path(os.getenv("LOCALAPPDATA") or os.getenv("XDG_CACHE_HOME") or Path.home() / '.cache') / 'hyfetch'


@dataclass
class GlobalConfig:
    # Global color mode default to 8-bit for compatibility
    color_mode: str
    override_distro: str | None
    debug: bool
    is_light: bool
    use_overlay: bool

    def light_dark(self) -> LightDark:
        return 'light' if self.is_light else 'dark'

    def default_lightness(self, term: LightDark | None = None) -> float:
        if term is None:
            term = self.light_dark()
        return 0.65 if term.lower() == 'dark' else 0.4


GLOBAL_CFG = GlobalConfig(color_mode='8bit', override_distro=None, debug=False, is_light=False, use_overlay=True)



#!/usr/bin/env python3
import math
import os
import shlex
from collections import Counter
from pathlib import Path
from subprocess import check_output

from github import Github
from github.PullRequest import PullRequest
import ruamel.yaml as yaml
from hypy_utils.tqdm_utils import tq, pmap, tmap


def obtain_resolved():
    """
    Obtain a list of resolved issues.
    """
    prefix = 'dylanaraps/neofetch#'
    commits = check_output(shlex.split('git log --pretty=format:"%s"')).decode().strip().split('\n')
    commits = [(c, c.find(prefix)) for c in commits]
    commits = [(c, i+len(prefix)) for c, i in commits if i != -1]
    return sorted([int(c[i:c.find(' ', i)]) for c, i in commits])


if __name__ == '__main__':
    # Obtain a list of resolved issues
    resolved = set(obtain_resolved())

    # Read the ignore-list
    with open(Path(__file__).parent / "pull_request_markings.yaml") as stream:
        ignore_list: dict[int, str] = yaml.safe_load(stream)['IgnoreList']
        ignore_list.update({r: 'merged' for r in resolved})

    # Obtain a list of open issues
    g = Github(per_page=100, login_or_token=os.environ.get('GH_TOKEN'))
    repo = g.get_repo('dylanaraps/neofetch')
    pager = repo.get_pulls(state='all')

    # Filter only unresolved issues
    pages = list(range(math.ceil(pager.totalCount // 100) + 1))
    pulls: list[list[PullRequest]] = tmap(pager.get_page, pages, desc='Crawling pull requests...', unit='page')
    pulls: set[PullRequest] = {p for lst in pulls for p in lst}
    unresolved: set[PullRequest] = {p for p in pulls if p.number not in resolved and p.number not in ignore_list}

    # Filter merged / closed
    draft = {p for p in unresolved if p.draft}
    unresolved -= draft
    merged = {p for p in unresolved if p.merged_at}
    unresolved -= merged
    closed = {p for p in unresolved if p.state == 'closed'}
    unresolved -= closed

    ignore_counter = Counter(ignore_list.values())
    hyfetch_merged = ignore_counter.pop('merged')
    print(f'Pull Request Statistics:')
    print(f'> {hyfetch_merged} PRs merged by HyFetch')
    print('\n'.join(f'> {c} PRs closed as {v} by HyFetch' for v, c in sorted(ignore_counter.items(), key=lambda x: -x[1])))
    print()
    print(f'> {len(draft)} PR drafts')
    print(f'> {len(merged)} PRs merged by neofetch')
    print(f'> {len(closed)} PRs closed without merging')
    print()
    print(f'> {len(unresolved)} open PRs that needs to be addressed:')
    print()

    opened = sorted(list(unresolved), key=lambda p: p.number)

    # Print unresolved issues
    print('\n'.join(f'[{p.number}] {p.title} {p.html_url}' for p in opened))



# This file is automatically generated. Please do not modify.

from . import AsciiArt

archcraft_ascii = AsciiArt(match=r'''"archcraft_ascii"*''', color='6 1 2 3 4 5', ascii=r"""
${c1}                   -o\
                  :ooo:
                 .ooooo.
                 ooooooo.
                +oooooooo.
               -oooooooooo.
              --:-+oooooooo.
             yooo+=+sooooooo.
            yoooooosooooooooo.
           y+ooooooooooooooooo.
          yoooooooooooooooooooo`
         yoooooo+oo=  :oo++ooooo`
        :oooooo.           +ooooo-
       -ooooooo.   .::.    +ooosoo=
      -oooooo`    .oooo`     +os-=o=
     =ooooooo=:    `oo+    :=ooo=--`.
    +ooooooooos.          .=sooooooo+-
  .+osossos+-`              `-+osososs+.
 :sss+=-:`                     `:-=+ssss:
:=-:`                                `-=+:
""")
    


import json
from pathlib import Path

from hyfetch.constants import CACHE_PATH
from hyfetch.neofetch_util import get_distro_name


def get_font_logo() -> str:
    cache = CACHE_PATH / 'font_logo_cache.txt'
    if cache.exists():
        return cache.read_text('utf-8')

    font_logos: dict[str, str] = json.loads((Path(__file__).parent / 'data/font_logos.json').read_text('utf-8'))
    font_logos = {k.lower(): v for k, v in font_logos.items()}

    # Get the distro
    distro = get_distro_name().lower()

    # Find most likely distro by containing string
    for k in font_logos.keys():
        if k in distro:
            distro = k
    # If not found, try matching partial string (by splitting with " ")
    if not distro:
        for k in font_logos.keys():
            if any(x in distro for x in k.split(' ')):
                distro = k
    # If still not found, give up
    if not distro:
        raise ValueError(f'No font logo found for distro: {distro}. The supported logos are in https://github.com/Lukas-W/font-logos')

    logo = font_logos[distro]
    cache.parent.mkdir(parents=True, exist_ok=True)
    cache.write_text(logo)

    return logo

